@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -81,7 +81,7 @@ public class InfostoreDocumentPublicationService extends AbstractPublicationServ
 
     private PublicationTarget buildTarget() {
         PublicationTarget target = new PublicationTarget();
-        target.setDisplayName("Publish Infostore Document");
+        target.setDisplayName(FormStrings.TARGET_NAME_INFOSTORE_DOCUMENT);
         target.setId("com.openexchange.publish.online.infostore.document");
         target.setModule("infostore/object");
         target.setPublicationService(this);
