@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -95,7 +95,7 @@ public class InfostorePublicationServlet extends HttpServlet {
 
     private static final long serialVersionUID = 8929899129435791832L;
 
-    private static final Log LOG = LogFactory.getLog(InfostorePublicationServlet.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(InfostorePublicationServlet.class));
 
     private static final String SELF_DESTRUCT = "selfDestruct";
 
@@ -157,7 +157,7 @@ public class InfostorePublicationServlet extends HttpServlet {
             final Context ctx = getContext(path);
             final String secret = getSecret(path);
             final Publication publication = getPublication(secret, ctx);
-            if(publication == null) {
+            if(publication == null || !publication.isEnabled()) {
                 resp.getWriter().println("Not Found");
                 resp.setStatus(HttpServletResponse.SC_NOT_FOUND);
                 return;
@@ -212,7 +212,7 @@ public class InfostorePublicationServlet extends HttpServlet {
             resp.setHeader("Content-Disposition", "attachment; filename=\""
                 + Helper.encodeFilename(fileName, "UTF-8", isIE(req)) + "\"");
         }
-   }
+    }
 
     private DocumentMetadata loadDocumentMetadata(final Publication publication) throws Exception {
         
